@@ -1,30 +1,17 @@
 from pathlib import Path
 
 import git
-
+from git.exc import GitCommandError
 from patchwork.common.client.scm import (
     GithubClient,
     GitlabClient,
     ScmPlatformClientProtocol,
+    get_slug_from_remote_url,
 )
 from patchwork.logger import logger
 from patchwork.step import Step
 
 
-def get_slug_from_remote_url(remote_url: str) -> str:
-    # TODO: consider using https://github.com/nephila/giturlparse instead
-    if remote_url.startswith("git@"):
-        # ssh
-        _, _, potential_slug = remote_url.partition(":")
-    else:
-        potential_slug = "/".join(remote_url.split("/")[-2:])
-
-    if potential_slug.endswith(".git"):
-        potential_slug = potential_slug[:-4]
-
-    return potential_slug
-
-
 class CreatePR(Step):
     required_keys = {"target_branch"}
 
@@ -34,20 +21,26 @@ class CreatePR(Step):
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
+        self.scm_client = None
         if "github_api_key" in inputs.keys():
             self.scm_client = GithubClient(inputs["github_api_key"])
         elif "gitlab_api_key" in inputs.keys():
             self.scm_client = GitlabClient(inputs["gitlab_api_key"])
         else:
-            raise ValueError(f'Missing required input data: "github_api_key" or "gitlab_api_key"')
+            logger.warning(f'Missing required input data: "github_api_key" or "gitlab_api_key",'
+                           f' PR creation will be disabled.')
 
-        if "scm_url" in inputs.keys():
-            self.scm_client.set_url(inputs["scm_url"])
+        if self.scm_client is not None:
+            if "scm_url" in inputs.keys():
+                self.scm_client.set_url(inputs["scm_url"])
 
-        if not self.scm_client.test():
-            raise ValueError(f"{self.scm_client.__class__.__name__} token test failed.")
+            if not self.scm_client.test():
+                raise ValueError(f"{self.scm_client.__class__.__name__} token test failed.")
+
+            self.enabled = not bool(inputs.get("disable_pr", False))
+        else:
+            self.enabled = False
 
-        self.enabled = not bool(inputs.get("disable_pr"))
         self.pr_body = inputs.get("pr_body", "")
         self.title = inputs.get("pr_title", "Patchwork PR")
         self.force = bool(inputs.get("force_pr_creation", False))
@@ -64,14 +57,19 @@ class CreatePR(Step):
         repo = git.Repo(Path.cwd(), search_parent_directories=True)
 
         if not self.enabled:
+            logger.warning(f"PR creation is disabled. Skipping PR creation.")
             return dict()
 
         original_remote_name = "origin"
-        original_remote_url = repo.remotes[original_remote_name].url
         push_args = ["--set-upstream", original_remote_name, self.target_branch]
         if self.force:
             push_args.insert(0, "--force")
-        repo.git.push(*push_args)
+
+        push(repo, push_args)
+        logger.debug(f"Pushed to {original_remote_name}/{self.target_branch}")
+
+        logger.info(f"Creating PR from {self.base_branch} to {self.target_branch}")
+        original_remote_url = repo.remotes[original_remote_name].url
         repo_slug = get_slug_from_remote_url(original_remote_url)
         url = create_pr(
             repo_slug=repo_slug,
@@ -83,11 +81,21 @@ class CreatePR(Step):
             force=self.force,
         )
 
-        logger.info(f"PR created at {url}")
+        logger.info(f"[green]PR created at [link={url}]{url}[/link][/]", extra={"markup": True})
         logger.info(f"Run completed {self.__class__.__name__}")
         return {"pr_url": url}
 
 
+def push(repo: git.Repo, args):
+    repo_git = repo.git
+    try:
+        with repo_git.custom_environment(GIT_TERMINAL_PROMPT="0"):
+            repo_git.push(*args)
+    except GitCommandError:
+        with logger.freeze():
+            repo_git.push(*args)
+
+
 def create_pr(
     repo_slug: str,
     body: str,
